# eric7.Plugins.VcsPlugins.vcsMercurial.HgUserConfigHostFingerprintDialog

Module implementing a dialog to edit a host fingerprint.

### Global Attributes

None

### Classes

HgUserConfigHostFingerprintDialog | Class implementing a dialog to edit a host fingerprint.

### Functions

None

## HgUserConfigHostFingerprintDialog

Class implementing a dialog to edit a host fingerprint.

### Derived from

QDialog, Ui_HgUserConfigHostFingerprintDialog

### Class Attributes

fingerprintLength
supportedHashes

### Class Methods

None

### Methods

HgUserConfigHostFingerprintDialog | Constructor
__updateOkButton | Private method to update the status of the Ok button.
getData | Public method to retrieve the data.
on_fingerprintEdit_textChanged | Private slot to handle changes of the fingerprint edit.
on_hashComboBox_currentIndexChanged | Private slot to handle changes of the hash combo.
on_hostEdit_textChanged | Private slot to handle changes of the host edit.

### Static Methods

None

#### HgUserConfigHostFingerprintDialog (Constructor)

HgUserConfigHostFingerprintDialog(parent=None, host="", fingerprint="", version=(0, 0, 0))

Constructor

parent (QWidget)
  reference to the parent widget
host (str)
  host name
fingerprint (str)
  fingerprint for the host
version (tuple of three integers)
  Mercurial version info

#### HgUserConfigHostFingerprintDialog.__updateOkButton

__updateOkButton()

Private method to update the status of the Ok button.

#### HgUserConfigHostFingerprintDialog.getData

getData()

Public method to retrieve the data.

Return:
  tuple containig the host name and the fingerprint

Return Type:
  tuple of two str

#### HgUserConfigHostFingerprintDialog.on_fingerprintEdit_textChanged

on_fingerprintEdit_textChanged(txt)

Private slot to handle changes of the fingerprint edit.

txt (str)
  current text

#### HgUserConfigHostFingerprintDialog.on_hashComboBox_currentIndexChanged

on_hashComboBox_currentIndexChanged(index)

Private slot to handle changes of the hash combo.

index (int)
  current index

#### HgUserConfigHostFingerprintDialog.on_hostEdit_textChanged

on_hostEdit_textChanged(txt)

Private slot to handle changes of the host edit.

txt (str)
  current text

Up